@@ -5,8 +5,8 @@
 # Distributed under the terms of the MIT License.
 from dataclasses import dataclass
 
+from telliot_core.dtypes.value_type import ValueType
 from telliot_core.queries.query import OracleQuery
-from telliot_core.types.value_type import ValueType
 
 
 @dataclass
